skippa package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   skippa.transformers

Submodules
----------

skippa.pipeline module
----------------------

.. automodule:: skippa.pipeline
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: skippa
   :members:
   :undoc-members:
   :show-inheritance:
